@@ -1,19 +1,34 @@
 # -*- coding: utf-8 -*-
 from xmpp import *
 
-import marshal
-import marshal as unmarshal
+import cPickle as marshal
+import cPickle as unmarshal
 import copy
+import threading
 
-db = {}
+mutex = threading.RLock()
 
+class DictWatch(dict):
+    def __init__(self, *args):
+        dict.__init__(self, args)
+
+    def __getitem__(self, key):
+        with mutex:
+            val = dict.__getitem__(self, key)
+        return val
+
+    def __setitem__(self, key, val):
+        with mutex:
+            dict.__setitem__(self, key, val)
+
+db = DictWatch()
 
 def build_database(server_instance):
     global db
     for a_registered_server in server_instance.servernames:
         server_instance.DEBUG('server', 'DB: Building database tree for %s' % a_registered_server, 'info')
         if a_registered_server not in db.keys():
-            db[a_registered_server] = {}
+            db[a_registered_server] = DictWatch()
 
         db[a_registered_server]['__ir__'] = {}
         db[a_registered_server]['__ir__']['storage'] = {'karma': {'down': 307200, 'up': 307200307200307200, 'last_time': 0.0, 'tot_down': 0, 'tot_up': 0}}
@@ -280,20 +295,29 @@ class DB(PlugIn):
     def save_groupie(self, domain, node, jid, groups):
         if not node:
             node, domain = domain.split(".", 1)
-        temp = []
-        for x in groups:
-            if type(x) == type(u''):
-                x = x.encode('utf-8')
-            elif type(x) == type(u''):
-                x = unicode(x).encode('utf-8')
-            temp += [x]
-        group_list = x
+        temp = [x for x in groups]
+        group_list = temp #[0] # will crash if empty!
         self.DEBUG("Saving groupie jid to database %s-->(%s) [%s]:\n" % (jid, node + '@' + domain, unicode(groups).encode('utf-8')), 'info')
-        for gn, gm in db[domain][node]['groups'].iteritems():
+        if db[domain][node]['groups'] == DictWatch():
+            for gn in group_list:
+                db[domain][node]['groups'][gn] = [jid]
+        '''for gn, gm in db[domain][node]['groups'].items():
             if gn not in group_list and jid in db[domain][node]['groups'][gn]:
                 db[domain][node]['groups'][gn].remove(jid)
             elif gn in group_list and jid not in db[domain][node]['groups'][gn]:
                 db[domain][node]['groups'][gn] += [jid]
+        '''
+        for gn in group_list:
+            if gn not in db[domain][node]['groups'].keys():
+                db[domain][node]['groups'][gn] = [jid]
+            else:
+                if jid not in db[domain][node]['groups'][gn]:
+                    db[domain][node]['groups'][gn] += [jid]
+        for gn,gm in db[domain][node]['groups'].items():
+            if (gn not in group_list) and (jid in gm):
+                db[domain][node]['groups'][gn].remove(jid)
+
+        self.DEBUG("Saved groupie jid to database %s-->(%s) [%s]:\n" % (jid, db[domain][node], unicode(groups).encode('utf-8')), 'info')
         self.save_database()
 
     def del_groupie(self, domain, node, jid):
@@ -333,14 +357,14 @@ class DB(PlugIn):
 
     def register_user(self, domain, node, password, name):
         try:
-            db[domain][node] = {}
+            db[domain][node] = DictWatch()
             db[domain][node]['password'] = password
-            db[domain][node]['roster'] = {}
-            db[domain][node]['storage'] = {}
-            db[domain][node]['groups'] = {}
+            db[domain][node]['roster'] = DictWatch()
+            db[domain][node]['storage'] =DictWatch()
+            db[domain][node]['groups'] = DictWatch()
             db[domain][node]['name'] = name
             db[domain][node]['anon_allow'] = 'yes'
-            db[domain][node]['roster'] = {}
+            db[domain][node]['roster'] = DictWatch()
             #db[domain][node]['roster'][domain] = {'subscription':'to','name':"Help Desk"}
             self.DEBUG("Registered user %s in domain %s" % (node, domain), 'info')
             self.save_database()
@@ -366,7 +390,8 @@ class DB(PlugIn):
                                         os.mkdir(tmpitem)
             """
             fh = open(filename, 'w')
-            marshal.dump(db, fh)
+            with mutex:
+                marshal.dump(db, fh)
             fh.close()
             self.DEBUG('save_database: User database saved!', 'info')
             return True
@@ -381,7 +406,8 @@ class DB(PlugIn):
         try:
             global db
             fh = open(filename, 'r')
-            db = unmarshal.load(fh)
+            with mutex:
+                db = unmarshal.load(fh)
             fh.close()
             self.DEBUG('load_database: User database loaded', 'info')
             return True
@@ -390,11 +416,17 @@ class DB(PlugIn):
             return False
 
     def __str__(self):
-        return str(db)
+        import pprint
+        pp = pprint.PrettyPrinter(indent=4)
+        with mutex:
+            return pp.pformat(db)
 
     @property
     def db(self):
         return db
 
     def print_database(self):
-        print str(self)
+        import pprint
+        pp = pprint.PrettyPrinter(indent=4)
+        with mutex:
+            pp.pprint(db)
